/*
 *	aegis - project change supervisor
 *	Copyright (C) 1995, 1996, 1998 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: insulate against <libintl.h> presence or absence
 */

#ifndef COMMON_AC_LIBINTL_H
#define COMMON_AC_LIBINTL_H

#include <config.h>

/*
 * if the libintl.h include file is available, include it
 */
#ifdef HAVE_LIBINTL_H
#include <libintl.h>
#else

/*
 * otherwise, provide a prototype and nothing else
 */
#include <main.h>
char *gettext _((const char *));
#endif /* !HAVE_LIBINTL_H */

#endif /* COMMON_AC_LIBINTL_H */
